/* libspf - Sender Policy Framework library
*
*  ANSI C implementation of draft-mengwong-spf-02.9.7.txt
*
*  Author: James Couzens <jcouzens@6o4.ca>
*  Author: Sean Comeau   <scomeau@obscurity.org>
*
*  FILE: spf.h
*  DESC: main library header file 
*
*  License:
*
*  The libspf Software License, Version 1.0
*
*  Copyright (c) 2004 James Couzens & Sean Comeau  All rights
*  reserved.
*
*  Redistribution and use in source and binary forms, with or without
*  modification, are permitted provided that the following conditions
*  are met:
*
*  1. Redistributions of source code must retain the above copyright
*     notice, this list of conditions and the following disclaimer.
*
*  2. Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in
*     the documentation and/or other materials provided with the
*     distribution.
*
*  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
*  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
*  OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
*  DISCLAIMED.  IN NO EVENT SHALL THE AUTHORS MAKING USE OF THIS LICESEN
*  OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
*  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
*  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
*  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
*  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
*  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
*  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
*  SUCH DAMAGE.
* 
*/


#ifndef	_MAIN_H
#define	_MAIN_H 1

#include <stdio.h>        /* stdin / stdout */
#include <stdlib.h>       /* malloc / free */
#include <string.h>       /* strstr / strdup */
#include <stdarg.h>       /* va_snprintf */

#include "spf.h"

__BEGIN_DECLS

#define FL_A            2           /* normal debugging */
#define FL_B            4           /* verbose debugging */
#define FL_C            8           /* normal and verbose debugging */
#define FL_D            16          /* profile results */
#define FL_E            32          /* normal debug + profile results */
#define FL_F            64          /* verbose debug + profile results */
#define FL_G            128         /* normal + verbose + profile results */

/* # limiting recursion */
#define SPF_RECURSE 20

/* spf MTA result strings */
#define RES_PASS    "domain of %s designates %s as permitted sender\r\n"
#define RES_NONE    "domain of %s does not designate permitted sender "   \
                    "hosts\r\n"
#define RES_S_FAIL  "transitioning domain of %s does not designate %s "   \
                    "as permitted sender\r\n"
#define RES_H_FAIL  "domain of %s does not designate %s as permitted "    \
                    "sender\r\n"
#define RES_ERROR   "encountered temporary error during SPF processing "  \
                    "of %s\r\n"
#define RES_NEUTRAL "%s is neither permitted nor denied by domain of "    \
                    "%s\r\n"
#define RES_UNKNOWN "error in processing during lookup of %s\r\n"
#define RES_UNMECH  "encountered unrecognized mechanism during SPF "      \
                    "processing of domain of %s\r\n"

/* header strings */
#define HDR_PASS    "pass (%s: domain of %s designates "    \
                    "%s as permitted sender) receiver=%s; client_ip=%s; " \
                    "envelope-from=%s;"
  
#define HDR_NONE    "none (%s: domain of %s does not "      \
                    "designate permitted sender hosts)"
  
#define HDR_S_FAIL  "softfail (%s: domain of "              \
                    "transitioning %s does not designate %s as "          \
                    "permitted sender) receiver=%s; client_ip=%s; "       \
                    "envelope-from=%s;"
  
#define HDR_H_FAIL  "fail (%s: domain of %s does not "      \
                    "designate %s as permitted sender) receiver=%s; "     \
                    "client_ip=%s; envelope-from=%s;"
  
#define HDR_ERROR   "error (%s: error in processing "       \
                    "during lookup of %s: %s)"
  
#define HDR_NEUTRAL "neutral  (%s: domain of %s is "        \
                    "neutral about designating %s as permitted sender)"
  
#define HDR_UNKNOWN "unknown (%s: domain of %s "            \
                    "encountered an error while parsing (check SPF "      \
                    "record %s for errors))"

#define HDR_UNMECH  "unknown -extension:%s (%s: domain of " \
                    "%s uses a mechanism not recognized by this client)"
                    
/*  Main library functions (spf.c) */
void        SPF_dbg_level(int level);
peer_info_t *SPF_init(const char *local, const char *rip, const char *expl,
              const char *tf, const char *guess, u_int32_t use_trust, 
              u_int32_t use_guess);
peer_info_t *SPF_close(peer_info_t *peer_info);
SPF_RESULT  SPF_policy_main(peer_info_t *peer_info);
SPF_BOOL    SPF_parse_policy(peer_info_t *peer_info, const char *policy);
char        *SPF_result(peer_info_t *peer_info);

SPF_BOOL    SPF_smtp_from(peer_info_t *peer_info, const char *s);
SPF_BOOL    SPF_smtp_helo(peer_info_t *peer_info, const char *s);

char        *SPF_build_header(peer_info_t *peer_info);
char        *SPF_get_explain(peer_info_t *peer_info);

__END_DECLS /* _MAIN_H */

#endif /* main.h */
